@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or
@@ -51,12 +50,15 @@ def info(message, prefix=None):
 
     _dispatch('info', _prefix(message, prefix))
 
-def error(message, prefix=None):
+def error(message, prefix=None, exit=False):
 
     """Shows an error message in the active tab in Konversation."""
 
     _dispatch('error', _prefix(message, prefix))
 
+    if exit:
+        sys.exit(1)
+
 def say(message, prefix=None):
 
     """
@@ -81,7 +83,7 @@ def _dispatch(*args):
 
     """Dispatch to Konversation's D-Bus API."""
 
-    subprocess.Popen(_dbus_command + args).communicate()
+    subprocess.call(_dbus_command + args)
 
 
 # Attributes
