@@ -50,7 +50,7 @@ Highlight_Config::Highlight_Config(QWidget* parent, const char* name)
             dir = *it;
             if ( dir.isReadable() && dir.count() > 2 )
             {
-                soundURL->setStartDir(QUrl(*it));
+                soundURL->setStartDir(QUrl::fromLocalFile(*it));
                 break;
             }
             ++it;
