@@ -23,13 +23,13 @@ class QuickButtons_Config : public QWidget, public KonviSettingsPage, private Ui
 
   public:
     explicit QuickButtons_Config(QWidget* parent, const char* name=NULL);
-    ~QuickButtons_Config();
+    ~QuickButtons_Config() override;
 
-    virtual void saveSettings();
-    virtual void loadSettings();
-    virtual void restorePageToDefaults();
+    void saveSettings() override;
+    void loadSettings() override;
+    void restorePageToDefaults() override;
 
-    virtual bool hasChanged();
+    bool hasChanged() override;
 
   Q_SIGNALS:
     void modified();
