@@ -18,27 +18,27 @@
 
 #include "ui_pasteeditor.h"
 
-#include <KDialog>
+#include <QDialog>
 
 class QAction;
 
-class PasteEditor : public KDialog, private Ui::PasteEditor
+class PasteEditor : public QDialog, private Ui::PasteEditor
 {
     Q_OBJECT
     public:
         explicit PasteEditor(QWidget* parent);
-        ~PasteEditor();
+        ~PasteEditor() override;
 
         void setText(const QString& text);
         QString text() const;
 
         static QString edit(QWidget* parent, const QString& text);
 
-    protected slots:
+    protected Q_SLOTS:
         void addQuotationIndicators();
         void removeNewlines();
 
-    private slots:
+    private Q_SLOTS:
         void doInlineAutoreplace();
 
     private:
